@@ -7,7 +7,7 @@ use Carp;
 use JSON::Syck;
 use XML::LibXML;
 
-our $VERSION='0.3';
+our $VERSION='0.4';
 
 =encoding utf-8
 
@@ -17,11 +17,11 @@ Geo::Coder::GoogleMaps::Location - Geo::Coder::GoogleMaps' Location object
 
 =head1 VERSION
 
-Version 0.3 (follow Geo::Coder::Google version number)
+Version 0.4 (follow L<Geo::Coder::GoogleMaps> version number)
 
 =head1 SYNOPSIS
 
-Here we have the object returned by Geo::Coder::GoogleMaps::Response->placemarks().
+Here we have the object returned by L<Geo::Coder::GoogleMaps::Response>->placemarks().
 
 This object can generate and manipulate the geocoding subset of KML 2.2 object (main change for the geocoding feature is the introduction of ExtendedData).
 
@@ -41,7 +41,7 @@ The constructor can take the following arguments :
 	- address
 	- longitude
 	- latitude
-	- altitude (warning in Google Map API altitude must be 0)
+	- altitude (warning in Google Maps API altitude must be 0)
 
 =cut
 
@@ -425,17 +425,17 @@ sub toXML {
 	return shift->toKML(@_);
 }
 
-=head2 Serialyze
+=head2 Serialize
 
 This method simply call the good to(JSON|XML|KML) depending of the output format you selected.
 
 You can eventually pass extra arguments, they will be relayed.
 
-	$location->Serialyze(1); # if the output is set to XML or KML you will have a stringified XML as output
+	$location->Serialize(1); # if the output is set to XML or KML you will have a stringified XML as output
 
 =cut
 
-sub Serialyze {
+sub Serialize {
 	my $self = shift;
 	if($self->{output}){
 		return $self->toJSON if($self->{output} eq 'json');
@@ -447,6 +447,18 @@ sub Serialyze {
 	}
 }
 
+=head2 Serialyze (OBSOLETE)
+
+This method is just an alias to Serialize(), it is kept for backward compatibility only.
+
+Please use the Serialize() method, this one is meant to be removed.
+
+=cut
+
+sub Serialyze {
+	return Serialize(@_);
+}
+
 sub _setData {
 	my ($self,$data)=@_;
 	$self->{data}=$data;
@@ -468,7 +480,7 @@ your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Geo::Coder::GoogleMaps
+    perldoc Geo::Coder::GoogleMaps::Location
 
 You can also look for information at:
 
@@ -506,6 +518,8 @@ L<http://search.cpan.org/dist/Geo-Coder-GoogleMaps>
 
 =head1 ACKNOWLEDGEMENTS
 
+Slaven Rezic (L<SREZIC>) for all the patches and his useful reports on RT.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2007 Arnaud DUPUIS and Nabla Development, all rights reserved.
